@@ -108,11 +108,13 @@ XPCOMUtils.defineLazyGetter(this, "CommonUI", function() {
   ["SelectionHelper", "chrome://browser/content/SelectionHelper.js"],
   ["ContentPopupHelper", "chrome://browser/content/ContentPopupHelper.js"],
   ["SharingUI", "chrome://browser/content/SharingUI.js"],
+  ["TabletSidebar", "chrome://browser/content/TabletSidebar.js"],
   ["TabsPopup", "chrome://browser/content/TabsPopup.js"],
   ["MasterPasswordUI", "chrome://browser/content/MasterPasswordUI.js"],
-//@line 114 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-scripts.js"
+//@line 115 "/usr/obj/ports/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-scripts.js"
   ["WeaveGlue", "chrome://browser/content/sync.js"],
-//@line 116 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-scripts.js"
+  ["SyncPairDevice", "chrome://browser/content/sync.js"],
+//@line 118 "/usr/obj/ports/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-scripts.js"
   ["WebappsUI", "chrome://browser/content/WebappsUI.js"],
   ["SSLExceptions", "chrome://browser/content/exceptions.js"],
   ["CapturePickerUI", "chrome://browser/content/CapturePickerUI.js"]
@@ -125,12 +127,12 @@ XPCOMUtils.defineLazyGetter(this, "CommonUI", function() {
   });
 });
 
-//@line 129 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-scripts.js"
+//@line 131 "/usr/obj/ports/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-scripts.js"
 XPCOMUtils.defineLazyGetter(this, "Weave", function() {
   Components.utils.import("resource://services-sync/main.js");
   return Weave;
 });
-//@line 134 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-scripts.js"
+//@line 136 "/usr/obj/ports/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-scripts.js"
 
 /**
  * Delay load some global scripts using a custom namespace
