@@ -45,9 +45,9 @@ Cu.import("resource://gre/modules/AddonManager.jsm");
   ["AllPagesList", "popup_autocomplete", "cmd_openLocation"],
   ["HistoryList", "history-items", "cmd_history"],
   ["BookmarkList", "bookmarks-items", "cmd_bookmarks"],
-//@line 49 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-ui.js"
+//@line 49 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-ui.js"
   ["RemoteTabsList", "remotetabs-items", "cmd_remoteTabs"]
-//@line 51 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-ui.js"
+//@line 51 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-ui.js"
 ].forEach(function(aPanel) {
   let [name, id, command] = aPanel;
   XPCOMUtils.defineLazyGetter(window, name, function() {
@@ -63,6 +63,7 @@ let Elements = {};
 [
   ["contentShowing",     "bcast_contentShowing"],
   ["urlbarState",        "bcast_urlbarState"],
+  ["mainKeyset",         "mainKeyset"],
   ["stack",              "stack"],
   ["tabList",            "tabs"],
   ["tabs",               "tabs-container"],
@@ -117,16 +118,18 @@ var BrowserUI = {
 
   _titleChanged: function(aBrowser) {
     let url = this.getDisplayURI(aBrowser);
-    let caption = aBrowser.contentTitle || url;
+    let contentTitle = aBrowser.contentTitle;
+    let caption = contentTitle || url;
+    let tabCaption = contentTitle || (Util.isURLEmpty(url) ? "" : url);
 
-    if (aBrowser.contentTitle == "" && !Util.isURLEmpty(aBrowser.userTypedValue))
-      caption = aBrowser.userTypedValue;
+    if (contentTitle == "" && !Util.isURLEmpty(aBrowser.userTypedValue))
+      caption = tabCaption = aBrowser.userTypedValue;
     else if (Util.isURLEmpty(url))
       caption = "";
 
     let tab = Browser.getTabForBrowser(aBrowser);
     if (tab)
-      tab.chromeTab.updateTitle(caption);
+      tab.chromeTab.updateTitle(tabCaption);
 
     let browser = Browser.selectedBrowser;
     if (browser && aBrowser != browser)
@@ -313,7 +316,7 @@ var BrowserUI = {
 
   // Will the on-screen keyboard cover the whole screen when opened?
   _isKeyboardFullscreen: function _isKeyboardFullscreen() {
-//@line 329 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-ui.js"
+//@line 332 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-ui.js"
     return false;
   },
 
@@ -397,7 +400,7 @@ var BrowserUI = {
     window.addEventListener("NavigationPanelHidden", this, false);
 
     Elements.browsers.addEventListener("PanFinished", this, true);
-//@line 415 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-ui.js"
+//@line 418 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-ui.js"
 
     // listen content messages
     messageManager.addMessageListener("DOMLinkAdded", this);
@@ -461,10 +464,10 @@ var BrowserUI = {
       DownloadsView.init();
       ConsoleView.init();
 
-//@line 479 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-ui.js"
+//@line 482 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-ui.js"
       // Init the sync system
       WeaveGlue.init();
-//@line 482 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-ui.js"
+//@line 485 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-ui.js"
 
       Services.prefs.addObserver("browser.ui.layout.tablet", BrowserUI, false);
       Services.obs.addObserver(BrowserSearch, "browser-search-engine-modified", false);
@@ -490,7 +493,7 @@ var BrowserUI = {
         alerts.showAlertNotification(image, Strings.browser.GetStringFromName("alertAddons"), label, false, "", null);
       }
 
-//@line 512 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-ui.js"
+//@line 515 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-ui.js"
     }, false);
 
     let panels = document.getElementById("panel-items");
@@ -508,7 +511,7 @@ var BrowserUI = {
         window[viewName].delayedInit();
     }, true);
 
-//@line 538 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-ui.js"
+//@line 541 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-ui.js"
   },
 
   uninit: function() {
@@ -870,7 +873,7 @@ var BrowserUI = {
       Browser.selectedTab = tab.owner;
       this.closeTab(tab);
     }
-//@line 906 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-ui.js"
+//@line 909 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-ui.js"
   },
 
   handleEvent: function handleEvent(aEvent) {
@@ -911,6 +914,10 @@ var BrowserUI = {
         break;
       // Window events
       case "keypress":
+        // Ignore events re-dispatched from content; we already
+        // handled them when they were originally fired.
+        if (aEvent.target == Elements.mainKeyset)
+          break;
         if (aEvent.keyCode == aEvent.DOM_VK_ESCAPE)
           this.handleEscape(aEvent);
         break;
@@ -1032,7 +1039,7 @@ var BrowserUI = {
         stmt.finalize();
 
         let download = dm.getDownload(json.id);
-//@line 1082 "/usr/obj/ports/fennec-9.0/mozilla-release/mobile/chrome/content/browser-ui.js"
+//@line 1089 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/browser-ui.js"
         try {
           DownloadsView.downloadCompleted(download);
           let element = DownloadsView.getElementForDownload(json.id);
@@ -1198,7 +1205,10 @@ var BrowserUI = {
         AppMenu.toggle();
         break;
       case "cmd_showTabs":
-        TabsPopup.toggle();
+        if (Util.isPortrait())
+          TabsPopup.toggle();
+        else
+          TabletSidebar.toggle();
         break;
       case "cmd_newTab":
         this.newTab();
