@@ -489,7 +489,7 @@ var FormHelperUI = {
     this._currentBrowser = Browser.selectedBrowser;
     this._currentCaretRect = null;
 
-//@line 493 "/usr/obj/fennec-9.0/mozilla-release/mobile/chrome/content/common-ui.js"
+//@line 493 "/usr/obj/ports/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/common-ui.js"
     // Update the next/previous commands
     this._cmdPrevious.setAttribute("disabled", !aHasPrevious);
     this._cmdNext.setAttribute("disabled", !aHasNext);
@@ -499,7 +499,7 @@ var FormHelperUI = {
       this._container.removeAttribute("disabled");
     else
       this._container.setAttribute("disabled", "true");
-//@line 506 "/usr/obj/fennec-9.0/mozilla-release/mobile/chrome/content/common-ui.js"
+//@line 506 "/usr/obj/ports/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/common-ui.js"
 
     this._open = true;
 
@@ -590,7 +590,7 @@ var FormHelperUI = {
         if (focusedElement && focusedElement.localName == "browser")
           return;
 
-        Browser.keySender.handleEvent(aEvent);
+        Browser.keyFilter.handleEvent(aEvent);
         break;
 
       case "SizeChanged":
