@@ -299,16 +299,14 @@ let Content = {
       // let's send it back to the chrome process to have it handle shortcuts
       case "keypress":
         let timer = new Util.Timeout(function() {
-          if(aEvent.getPreventDefault())
-            return;
-
           let eventData = {
             ctrlKey: aEvent.ctrlKey,
             altKey: aEvent.altKey,
             shiftKey: aEvent.shiftKey,
             metaKey: aEvent.metaKey,
             keyCode: aEvent.keyCode,
-            charCode: aEvent.charCode
+            charCode: aEvent.charCode,
+            preventDefault: aEvent.getPreventDefault()
           };
           sendAsyncMessage("Browser:KeyPress", eventData);
         });
@@ -467,7 +465,7 @@ let Content = {
         if (!element)
           return;
 
-//@line 479 "/usr/ports/pobj/fennec-9.0/mozilla-release/mobile/chrome/content/content.js"
+//@line 477 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/content.js"
 
         ContextHandler.messageId = json.messageId;
 
@@ -492,10 +490,11 @@ let Content = {
           break;
         }
 
-        if (!this.formAssistant.open(element))
+        if (!this.formAssistant.open(element, x, y))
           sendAsyncMessage("FindAssist:Hide", { });
 
-        if (this._highlightElement) {
+        // don't fire mouse events on selects, see bug 685197
+        if (this._highlightElement && !(element instanceof HTMLSelectElement)) {
           this._sendMouseEvent("mousemove", this._highlightElement, x, y);
           this._sendMouseEvent("mousedown", this._highlightElement, x, y);
           this._sendMouseEvent("mouseup", this._highlightElement, x, y);
@@ -892,6 +891,7 @@ var ContextHandler = {
     }
 
     let elem = popupNode;
+    let isText = false;
     while (elem) {
       if (elem.nodeType == Ci.nsIDOMNode.ELEMENT_NODE) {
         // Link?
@@ -940,14 +940,16 @@ var ContextHandler = {
                    elem instanceof Ci.nsIDOMHTMLPreElement ||
                    elem instanceof Ci.nsIDOMHTMLHeadingElement ||
                    elem instanceof Ci.nsIDOMHTMLTableCellElement) {
-          state.types.push("content-text");
-          break;
+          isText = true;
         }
       }
 
       elem = elem.parentNode;
     }
 
+    if (isText)
+      state.types.push("content-text");
+    
     for (let i = 0; i < this._types.length; i++)
       if (this._types[i].handler(state, popupNode))
         state.types.push(this._types[i].name);
@@ -1359,9 +1361,9 @@ var TouchEventHandler = {
     let touches = content.document.createTouchList(point);
     if (aName == "touchend") {
       let empty = content.document.createTouchList();
-      evt.initTouchEvent(aName, true, true, content, 0, true, true, true, true, empty, empty, touches);      
+      evt.initTouchEvent(aName, true, true, content, 0, false, false, false, false, empty, empty, touches);
     } else {
-      evt.initTouchEvent(aName, true, true, content, 0, true, true, true, true, touches, touches, touches);
+      evt.initTouchEvent(aName, true, true, content, 0, false, false, false, false, touches, touches, touches);
     }
     return aElement.dispatchEvent(evt);
   }
@@ -1560,3 +1562,53 @@ var SelectionHandler = {
 };
 
 SelectionHandler.init();
+
+
+var PluginHandler = {
+  init: function() {
+    addEventListener("PluginClickToPlay", this, false);
+  },
+
+  addLinkClickCallback: function (linkNode, callbackName /*callbackArgs...*/) {
+     // XXX just doing (callback)(arg) was giving a same-origin error. bug?
+     let self = this;
+     let callbackArgs = Array.prototype.slice.call(arguments).slice(2);
+     linkNode.addEventListener("click",
+                               function(evt) {
+                                 if (!evt.isTrusted)
+                                   return;
+                                 evt.preventDefault();
+                                 if (callbackArgs.length == 0)
+                                   callbackArgs = [ evt ];
+                                 (self[callbackName]).apply(self, callbackArgs);
+                               },
+                               true);
+ 
+     linkNode.addEventListener("keydown",
+                               function(evt) {
+                                 if (!evt.isTrusted)
+                                   return;
+                                 if (evt.keyCode == evt.DOM_VK_RETURN) {
+                                   evt.preventDefault();
+                                   if (callbackArgs.length == 0)
+                                     callbackArgs = [ evt ];
+                                   evt.preventDefault();
+                                   (self[callbackName]).apply(self, callbackArgs);
+                                 }
+                               },
+                               true);
+   },
+
+  handleEvent : function(event) {
+    if (event.type != "PluginClickToPlay")
+      return;
+    let plugin = event.target;
+    PluginHandler.addLinkClickCallback(plugin, "reloadToEnablePlugin");
+  },
+
+  reloadToEnablePlugin: function() {
+    sendAsyncMessage("Browser:PluginClickToPlayClicked", { });
+  }
+};
+
+PluginHandler.init();
