@@ -42,9 +42,9 @@ const PREF_GETADDONS_MAXRESULTS = "extensions.getAddons.maxResults";
 
 const kAddonPageSize = 5;
 
-//@line 48 "/usr/ports/pobj/fennec-9.0/mozilla-release/mobile/chrome/content/extensions.js"
+//@line 48 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/extensions.js"
 const URI_GENERIC_ICON_XPINSTALL = "chrome://browser/skin/images/alert-addons-30.png";
-//@line 50 "/usr/ports/pobj/fennec-9.0/mozilla-release/mobile/chrome/content/extensions.js"
+//@line 50 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/extensions.js"
 const ADDONS_NOTIFICATION_NAME = "addons";
 
 XPCOMUtils.defineLazyGetter(this, "AddonManager", function() {
@@ -57,6 +57,11 @@ XPCOMUtils.defineLazyGetter(this, "AddonRepository", function() {
   return AddonRepository;
 });
 
+XPCOMUtils.defineLazyGetter(this, "NetUtil", function() {
+  Cu.import("resource://gre/modules/NetUtil.jsm");
+  return NetUtil;
+});
+
 var ExtensionsView = {
   _strings: {},
   _list: null,
@@ -414,6 +419,34 @@ var ExtensionsView = {
     aItem.setAttribute("opType", opType);
   },
 
+  _getLocalesInAddon: function(aAddon, aCallback) {
+    if (!aCallback || typeof aCallback != "function")
+      throw "_getLocalesInAddon requires a callback function";
+
+    let uri = aAddon.getResourceURI("chrome.manifest");
+    NetUtil.asyncFetch(uri, function(aStream, aResult, aRequest) {
+      var data = NetUtil.readInputStreamToString(aStream, aStream.available());
+      let reg = new RegExp("locale browser ([a-zA-Z\-]*)", "g");
+      let res = reg.exec(data)
+      let list = [];
+      while(res) {
+        if (list.indexOf(res[1]) == -1)
+          list.push(res[1]);
+        res = reg.exec(data);
+      }
+      if (aCallback)
+        aCallback(list);
+    });
+  },
+
+  _resetLanguagePref: function(aAddon) {
+      this._getLocalesInAddon(aAddon, function(aLocales) {
+        let currentLocale = Services.prefs.getCharPref("general.useragent.locale");
+        if (aLocales.indexOf(currentLocale) > -1)
+          Services.prefs.clearUserPref("general.useragent.locale");
+      });    
+  },
+
   disable: function ev_disable(aItem) {
     let opType;
     if (aItem.getAttribute("type") == "search") {
@@ -424,7 +457,7 @@ var ExtensionsView = {
       aItem.addon.userDisabled = true;
       aItem.setAttribute("isDisabled", true);
     } else if (aItem.getAttribute("type") == "locale") {
-      Services.prefs.clearUserPref("general.useragent.locale");
+      this._resetLanguagePref(aItem.addon);
       aItem.addon.userDisabled = true;
       aItem.setAttribute("isDisabled", true);
     } else {
@@ -473,6 +506,9 @@ var ExtensionsView = {
       } else {
         this._list.removeChild(aItem);
       }
+
+      if (aItem.getAttribute("type") == "locale")
+        this._resetLanguagePref(aItem.addon);
     }
   },
 
@@ -843,7 +879,7 @@ var ExtensionsView = {
   },
 
   hideAlerts: function ev_hideAlerts() {
-//@line 854 "/usr/ports/pobj/fennec-9.0/mozilla-release/mobile/chrome/content/extensions.js"
+//@line 890 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/extensions.js"
 
     // Keep our preference in sync
     Services.prefs.clearUserPref("browser.notifications.pending.addons");
@@ -996,7 +1032,7 @@ AddonInstallListener.prototype = {
   onDownloadProgress: function xpidm_onDownloadProgress(aInstall) {
     let element = ExtensionsView.getElementForAddon(aInstall.sourceURI.spec);
 
-//@line 1012 "/usr/ports/pobj/fennec-9.0/mozilla-release/mobile/chrome/content/extensions.js"
+//@line 1048 "/usr/obj/fennec-10.0.5/mozilla-esr10/mobile/chrome/content/extensions.js"
 
     if (!element)
       return;
