@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/ports/fennec-9.0/mozilla-release/toolkit/content/aboutSupport.js"
+//@line 38 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/content/aboutSupport.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -15,10 +15,10 @@ const ELLIPSIS = Services.prefs.getComplexValue("intl.ellipsis",
 // under the "accessibility.*" branch.
 const PREFS_WHITELIST = [
   "accessibility.",
+  "browser.display.",
   "browser.fixup.",
   "browser.history_expire_",
   "browser.link.open_newwindow",
-  "browser.mousewheel.",
   "browser.places.",
   "browser.startup.homepage",
   "browser.tabs.",
@@ -27,6 +27,7 @@ const PREFS_WHITELIST = [
   "extensions.checkCompatibility",
   "extensions.lastAppVersion",
   "font.",
+  "general.autoScroll",
   "general.useragent.",
   "gfx.",
   "html5.",
@@ -34,7 +35,9 @@ const PREFS_WHITELIST = [
   "javascript.",
   "keyword.",
   "layout.css.dpi",
+  "mousewheel.",
   "network.",
+  "permissions.default.image",
   "places.",
   "plugin.",
   "plugins.",
@@ -209,7 +212,7 @@ function populateGraphicsSection() {
     pushInfoRow(trGraphics, "driverVersion", gfxInfo.adapterDriverVersion);
     pushInfoRow(trGraphics, "driverDate", gfxInfo.adapterDriverDate);
 
-//@line 285 "/usr/obj/ports/fennec-9.0/mozilla-release/toolkit/content/aboutSupport.js"
+//@line 288 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/content/aboutSupport.js"
 
     var webglrenderer;
     var webglenabled;
@@ -220,9 +223,9 @@ function populateGraphicsSection() {
       webglrenderer = false;
       webglenabled = false;
     }
-//@line 303 "/usr/obj/ports/fennec-9.0/mozilla-release/toolkit/content/aboutSupport.js"
+//@line 306 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/content/aboutSupport.js"
     var webglfeature = gfxInfo.FEATURE_WEBGL_OPENGL;
-//@line 305 "/usr/obj/ports/fennec-9.0/mozilla-release/toolkit/content/aboutSupport.js"
+//@line 308 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/content/aboutSupport.js"
     pushFeatureInfoRow(trGraphics, "webglRenderer", webglfeature, webglenabled, webglrenderer);
 
     appendChildren(graphics_tbody, trGraphics);
@@ -257,9 +260,9 @@ function populateGraphicsSection() {
   if (acceleratedWindows) {
     msg += " " + mgrType;
   } else {
-//@line 342 "/usr/obj/ports/fennec-9.0/mozilla-release/toolkit/content/aboutSupport.js"
+//@line 345 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/content/aboutSupport.js"
     var feature = gfxInfo.FEATURE_OPENGL_LAYERS;
-//@line 344 "/usr/obj/ports/fennec-9.0/mozilla-release/toolkit/content/aboutSupport.js"
+//@line 347 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/content/aboutSupport.js"
     var errMsg = errorMessageForFeature(feature);
     if (errMsg)
       msg += ". " + errMsg;
@@ -391,7 +394,7 @@ function createTextForElement(elem) {
   text = text.replace(/\n\n\n+/g, "\n\n");
 
   // Actual CR/LF pairs are needed for some Windows text editors.
-//@line 478 "/usr/obj/ports/fennec-9.0/mozilla-release/toolkit/content/aboutSupport.js"
+//@line 481 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/content/aboutSupport.js"
 
   return text;
 }
