@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/ports/fennec-9.0/mozilla-release/toolkit/content/customizeToolbar.js"
+//@line 40 "/usr/ports/pobj/fennec-10.0.5/mozilla-esr10/toolkit/content/customizeToolbar.js"
 
 const kRowMax = 4;
 
@@ -191,7 +191,7 @@ function wrapToolbarItems()
 {
   forEachCustomizableToolbar(function (toolbar) {
     Array.forEach(toolbar.childNodes, function (item) {
-//@line 236 "/usr/obj/ports/fennec-9.0/mozilla-release/toolkit/content/customizeToolbar.js"
+//@line 236 "/usr/ports/pobj/fennec-10.0.5/mozilla-esr10/toolkit/content/customizeToolbar.js"
       if (isToolbarItem(item)) {
         let wrapper = wrapToolbarItem(item);
         cleanupItemForToolbar(item, wrapper);
@@ -716,7 +716,7 @@ function onToolbarDragStart(aEvent)
 function onToolbarDragOver(aEvent)
 {
   var documentId = gToolboxDocument.documentElement.id;
-  if (!aEvent.dataTransfer.types.contains("text/toolbarwrapper-id/" + documentId))
+  if (!aEvent.dataTransfer.types.contains("text/toolbarwrapper-id/" + documentId.toLowerCase()))
     return;
 
   var toolbar = aEvent.target;
@@ -876,7 +876,7 @@ function onToolbarDrop(aEvent)
 function onPaletteDragOver(aEvent)
 {
   var documentId = gToolboxDocument.documentElement.id;
-  if (aEvent.dataTransfer.types.contains("text/toolbarwrapper-id/" + documentId))
+  if (aEvent.dataTransfer.types.contains("text/toolbarwrapper-id/" + documentId.toLowerCase()))
     aEvent.preventDefault();
 }
 
