@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/fennec-9.0/mozilla-release/toolkit/components/viewsource/content/viewSource.js"
+//@line 40 "/usr/ports/pobj/fennec-10.0.5/mozilla-esr10/toolkit/components/viewsource/content/viewSource.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -335,10 +335,12 @@ function ViewSourceReload()
                            Ci.nsIWebNavigation.LOAD_FLAGS_BYPASS_CACHE);
 }
 
-// Strips the |view-source:| for saveURL()
+// Strips the |view-source:| for internalSave()
 function ViewSourceSavePage()
 {
-  saveURL(window.content.location.href.substring(12), null, "SaveLinkTitle");
+  internalSave(window.content.location.href.substring(12), 
+               null, null, null, null, null,
+               "SaveLinkTitle", null, null, null, gPageLoader);
 }
 
 var PrintPreviewListener = {
@@ -731,3 +733,39 @@ function UpdateBackForwardCommands() {
   else
     forwardBroadcaster.setAttribute("disabled", "true");
 }
+
+// FIXME copied and modified from browser.js.
+// Deduplication is part of bug 480356.
+function FillInHTMLTooltip(tipElement)
+{
+  var retVal = false;
+  var titleText = null;
+  var direction = tipElement.ownerDocument.dir;
+
+  while (!titleText && tipElement) {
+    if (tipElement.nodeType == Node.ELEMENT_NODE) {
+      titleText = tipElement.getAttribute("title");
+      var defView = tipElement.ownerDocument.defaultView;
+      // XXX Work around bug 350679:
+      // "Tooltips can be fired in documents with no view".
+      if (!defView)
+        return retVal;
+      direction = defView.getComputedStyle(tipElement, "")
+        .getPropertyValue("direction");
+    }
+    tipElement = tipElement.parentNode;
+  }
+
+  var tipNode = document.getElementById("aHTMLTooltip");
+  tipNode.style.direction = direction;
+
+  if (titleText && /\S/.test(titleText)) {
+    // Make CRLF and CR render one line break each.  
+    titleText = titleText.replace(/\r\n/g, '\n');
+    titleText = titleText.replace(/\r/g, '\n');
+    tipNode.setAttribute("label", titleText);
+    retVal = true;
+  }
+  return retVal;
+}
+
