@@ -1,4 +1,4 @@
-//@line 45 "/usr/ports/pobj/fennec-9.0/mozilla-release/toolkit/mozapps/downloads/content/downloads.js"
+//@line 45 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/mozapps/downloads/content/downloads.js"
 
 ////////////////////////////////////////////////////////////////////////////////
 //// Globals
@@ -249,7 +249,7 @@ function openDownload(aDownload)
       dontAsk = !pref.getBoolPref(PREF_BDM_ALERTONEXEOPEN);
     } catch (e) { }
 
-//@line 307 "/usr/ports/pobj/fennec-9.0/mozilla-release/toolkit/mozapps/downloads/content/downloads.js"
+//@line 307 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/mozapps/downloads/content/downloads.js"
 
     if (!dontAsk) {
       var strings = document.getElementById("downloadStrings");
@@ -357,7 +357,7 @@ function onUpdateProgress()
   var base = 0;
   var dls = gDownloadManager.activeDownloads;
   while (dls.hasMoreElements()) {
-    let dl = dls.getNext().QueryInterface(Ci.nsIDownload);
+    let dl = dls.getNext();
     if (dl.percentComplete < 100 && dl.size > 0) {
       mean += dl.amountTransferred;
       base += dl.size;
@@ -433,7 +433,7 @@ function Startup()
     }
   }, false);
 
-//@line 495 "/usr/ports/pobj/fennec-9.0/mozilla-release/toolkit/mozapps/downloads/content/downloads.js"
+//@line 495 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/mozapps/downloads/content/downloads.js"
 }
 
 function Shutdown()
@@ -489,11 +489,11 @@ let gDownloadObserver = {
         }
         break;
       case "browser-lastwindow-close-granted":
-//@line 551 "/usr/ports/pobj/fennec-9.0/mozilla-release/toolkit/mozapps/downloads/content/downloads.js"
+//@line 551 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/mozapps/downloads/content/downloads.js"
         if (gDownloadManager.activeDownloadCount == 0) {
           setTimeout(gCloseDownloadManager, 0);
         }
-//@line 555 "/usr/ports/pobj/fennec-9.0/mozilla-release/toolkit/mozapps/downloads/content/downloads.js"
+//@line 555 "/usr/obj/fennec-10.0.5/mozilla-esr10/toolkit/mozapps/downloads/content/downloads.js"
         break;
     }
   }
