@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/fennec-9.0/mozilla-release/toolkit/mozapps/extensions/content/update.js"
+//@line 38 "/usr/ports/pobj/fennec-10.0.5/mozilla-esr10/toolkit/mozapps/extensions/content/update.js"
 
 // This UI is only opened from the Extension Manager when the app is upgraded.
 
@@ -6,9 +6,11 @@
 
 const PREF_UPDATE_EXTENSIONS_ENABLED            = "extensions.update.enabled";
 const PREF_XPINSTALL_ENABLED                    = "xpinstall.enabled";
+const PREF_EM_HOTFIX_ID                         = "extensions.hotfix.id";
 
 Components.utils.import("resource://gre/modules/Services.jsm");
 Components.utils.import("resource://gre/modules/AddonManager.jsm");
+Components.utils.import("resource://gre/modules/AddonRepository.jsm");
 
 var gUpdateWizard = {
   // When synchronizing app compatibility info this contains all installed
@@ -122,17 +124,30 @@ var gVersionInfoPage = {
                                   "nextButtonText", true,
                                   "cancelButtonText", false);
 
+    try {
+      var hotfixID = Services.prefs.getCharPref(PREF_EM_HOTFIX_ID);
+    }
+    catch (e) { }
+
     // Retrieve all add-ons in order to sync their app compatibility information
     AddonManager.getAllAddons(function(aAddons) {
       gUpdateWizard.addons = aAddons.filter(function(a) {
-        return a.type != "plugin";
+        return a.type != "plugin" && a.id != hotfixID;
       });
 
       gVersionInfoPage._totalCount = gUpdateWizard.addons.length;
 
-      gUpdateWizard.addons.forEach(function(aAddon) {
-        aAddon.findUpdates(gVersionInfoPage, AddonManager.UPDATE_WHEN_NEW_APP_INSTALLED);
-      }, this);
+      // Ensure compatibility overrides are up to date before checking for
+      // individual addon updates.
+      let ids = [addon.id for each (addon in gUpdateWizard.addons)];
+      AddonRepository.repopulateCache(ids, function() {
+        AddonManagerPrivate.updateAddonRepositoryData(function() {
+
+          gUpdateWizard.addons.forEach(function(aAddon) {
+            aAddon.findUpdates(gVersionInfoPage, AddonManager.UPDATE_WHEN_NEW_APP_INSTALLED);
+          }, this);
+        });
+      });
     });
   },
 
